"use strict";
/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const theme_1 = require("../../theme");
/**
 * `Avatar` is a styled `Image` component.
 *
 * @extends React.Component
 *
 * @property {string} shape - Determines the shape of the component.
 * Can be `round`, `rounded` or `square`.
 * Default is `round`.
 *
 * @property {string} size - Determines the size of the component.
 * Can be `tiny`, `small`, `medium`, `large`, or `giant`.
 * Default is `medium`.
 *
 * @property {ImageProps} ...ImageProps - Any props applied to Image component.
 *
 * @overview-example AvatarSimpleUsage
 *
 * @overview-example AvatarSize
 *
 * @overview-example AvatarShape
 *
 * @example AvatarRemoteImages
 *
 * @example AvatarInlineStyling
 */
class AvatarComponent extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.getComponentStyle = (source) => {
            const { roundCoefficient, ...containerParameters } = source;
            // @ts-ignore: avoid checking `containerParameters`
            const baseStyle = react_native_1.StyleSheet.flatten([
                containerParameters,
                this.props.style,
            ]);
            // @ts-ignore: rhs operator is restricted to be number
            const borderRadius = roundCoefficient * baseStyle.height;
            return {
                borderRadius,
                ...baseStyle,
            };
        };
    }
    render() {
        const { themedStyle, ...restProps } = this.props;
        const componentStyle = this.getComponentStyle(themedStyle);
        return (react_1.default.createElement(react_native_1.Image, Object.assign({}, restProps, { style: componentStyle })));
    }
}
exports.AvatarComponent = AvatarComponent;
AvatarComponent.styledComponentName = 'Avatar';
exports.Avatar = theme_1.styled(AvatarComponent);
//# sourceMappingURL=avatar.component.js.map